DEFAULT_OPTIONS = {
    'remove_comments': True,
    'strip_lines': True
}

# Replace without regex
replace_simple = [
    ['\n$$', '\n$$\n'],
    ['$$\n', '\n$$\n'],
    [r'\[', '\n$$\n'],
    [r'\]', '\n$$\n'],
]

# Deleted with TexSoup
del_commands = ['vspace',
                'Bareme',
                'cornouaille',
                'renewcommand',
                'setbar',
                'esp',
                'encadre',
                'ref',
                'arraycolsep',
                'label',
                'renewcommand',
                'hspace',
                'parindent',
                'raisebox',
                'rhead',
                'lhead',
                'lfoot',
                'rfoot',
                'addtolength',
                'pagestyle',
                'thispagestyle',
                'marginpar',
                'newpage',
                'hfill',
                'medskip',
                'bigskip',
                'smallskip',
                'setlength',
                'decofourleft',
                'footrulewidth',
                'decofourright'
                ]

del_environnements = [r'\begin{center}', r'\end{center}']

del_blocks = ['center']

replace_commands = [['chapter', '# S_T_R'],
                    ['section', '## S_T_R'],
                    ['subsection', '### S_T_R'],
                    ['textbf', '**S_T_R**'],
                    ['textsc', 'S_T_R'],
                    ['emph', '_S_T_R_'],
                    ['Large', 'S_T_R']
                   ]

math_sub = [[r"\\np\{((?P<arg>.*?))\}",r'\1'],
[r"\\vect\{((?P<arg>.*?))\}", r"\\overrightarrow{\1}"]]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['latextomd']

package_data = \
{'': ['*']}

install_requires = \
['TexSoup>=0.2.0,<0.3.0']

entry_points = \
{'console_scripts': ['latextomd = latextomd.cli:main']}

setup_kwargs = {
    'name': 'latextomd',
    'version': '0.1.2',
    'description': 'Simple project to convert latex in markdown',
    'long_description': '# latextomd\n\nA simple python package to convert latex to markdown (katex)\n\n## Installation\n\n```bash\npip install latextomd\n```\n\n## Basic usage\n\n```bash\nlatextomd source.tex export.md\n```\n\n',
    'author': 'David Couronné',
    'author_email': 'couronne.david@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/DavidCouronne/latextomd',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import re

from latextomd import config
from latextomd.soup import Latex
from latextomd.text_manipulation import LatexString





def _process_preamble(latex_string):
    """Detect latex preamble"""
    if r"\begin{document}" in latex_string:
        preamble, content = latex_string.split(r"\begin{document}")
        if r"\end{document}" in content:
            content = content.split(r"\end{document}")[0]
    else:
        preamble = 'default header\n'
        content = latex_string
    return preamble, content


def _strip_lines(latex_string):
    lines = latex_string.splitlines()
    result = []
    for line in lines:
        result.append(line.strip())
    return '\n'.join(result)


def _clean_lines(latex_string):
    lines = latex_string.splitlines()
    while lines[0] == '':
        lines = lines[1:]
    while lines[-1] == '':
        lines = lines[:-1]
    content = '\n'.join(lines)
    while '\n\n\n' in content:
        content = content.replace('\n\n\n', '\n\n')
    return content


def _delete_blocks(latex_string):
    content = latex_string
    for env in config.del_environnements:
        content = content.replace(env, '')
    return content


def to_markdown(latex_string, export_file_name=""):
    content = latex_string
    content = _strip_lines(content)
   
    preamble, content = _process_preamble(content)
    content = LatexString(content).process()
    content = Latex(content).process()
    content = _delete_blocks(content)
    content = _strip_lines(content)

    content = _clean_lines(content)
    return content



import codecs
import sys

from latextomd import latextomd


def predict_encoding(file_path, n_lines=20):
    '''Predict a file's encoding using chardet'''
    import chardet

    # Open the file as binary data
    with open(file_path, 'rb') as f:
        # Join binary lines for specified number of lines
        rawdata = b''.join([f.readline() for _ in range(n_lines)])

    return chardet.detect(rawdata)['encoding']


def main():
    if len(sys.argv) == 1:
        print('Basic usage: latextomd source.tex export.md')
    else:
        if len(sys.argv) == 2:
            source_file = sys.argv[1]
            export_file = source_file.replace('.tex', '.md')
        elif len(sys.argv) == 3:
            source_file = sys.argv[1]
            export_file = sys.argv[2]

        print(predict_encoding(source_file))

        with codecs.open(source_file, 'r', 'utf-8') as f:
            latex_string = f.read()
            markdown_string = latextomd.to_markdown(latex_string, export_file)
            with codecs.open(export_file, 'w', 'utf-8') as f_out:
                f_out.write(markdown_string)


if __name__ == '__main__':
    main()



import re

from latextomd import config


class LatexString(object):
    def __init__(self, latex_string):
        self.content = latex_string

    def process(self):
        self._remove_comments()
        self._replace_simple()
        self._math_replace()
        self._convertEnumerate()
        return self.content

    def _remove_comments(self):
        self.content = re.sub('(?<!\\\\)%.*$', '', self.content, flags=re.M)
    
    def _replace_simple(self):
        for replace_simple in config.replace_simple:
            self.content = self.content.replace(replace_simple[0],replace_simple[1])

    def _math_replace(self):
        for item in config.math_sub:
            p=re.compile(item[0])
            self.content = p.sub(item[1],self.content)
    
    def _convertEnumerate(self):
        """Agit sur les lignes.
        Converti les environnements enumerate en listes html"""
        level_enumerate = 0
        enumi = 0
        enumii = 0
        new_lines = []
        arabic = "abcdefghijklmnopqrstuvwxz"
        self.lines = self.content.splitlines()

        for line in self.lines:
            if r"\begin{enumerate}" in line or r"\begin{colenumerate}" in line:
                level_enumerate = level_enumerate + 1
                line = ""
            elif r"\end{enumerate}" in line or r"\end{colenumerate}" in line:
                if level_enumerate == 2:
                    enumii = 0
                else:
                    enumi = 0
                level_enumerate = level_enumerate - 1
                line = ""
            elif r"\item" in line and level_enumerate != 0:
                if level_enumerate == 1:
                    enumi = enumi + 1
                    line = line.replace(r"\item", str(enumi)+". ")
                    line = "\n\n" + line
                else:
                    line = line.replace(r"\item", arabic[enumii]+") ")
                    enumii = enumii + 1
                    line = "\n\n" + line
            new_lines.append(line)
        self.lines = new_lines
        self.content = '\n'.join(self.lines)
